@@ -2,15 +2,17 @@
 # mypy: ignore-errors
 import sys
 import warnings
+from typing import Any
 
-
-warnings.warn("josepy.magic_typing is deprecated and will be removed in a future release.",
-              DeprecationWarning)
+warnings.warn(
+    "josepy.magic_typing is deprecated and will be removed in a future release.", DeprecationWarning
+)
 
 
 class TypingClass:
     """Ignore import errors by getting anything"""
-    def __getattr__(self, name):
+
+    def __getattr__(self, name: str) -> Any:
         return None
 
 
